@@ -8,10 +8,10 @@ import f61d.LOGO as LOGO
 #from f61d.__version__ import *
 from math import ceil
 from tqdm import *
-from f61d.setu import setu,getDesktop
+from f61d.setu import *
 
 
-VERSION = (0,5,6)
+VERSION = (0,5,7)
 VERSION = '.'.join(map(str, VERSION))
 
 
@@ -35,7 +35,7 @@ help_cont[11] = 'gmgj    : Common Modulus Attack in RSA'
 help_cont[12] = 'crt     : Chinese Remainder Theory'
 help_cont[13] = 'mtank   : 幻影坦克 Mirage tank maker'
 help_cont[14] = 'setu    : get a setu with your xp'
-help_cont[15] = 'fastsetu: get a random setu'
+help_cont[15] = 'fast_setu: get a random setu'
 
 
 
